import 'package:basic_ui/basic_ui.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';

final _formModelProvider = StateProvider.autoDispose(
  (ref) => _FormModel(
    textField: "",
    toggle: false,
  ),
);

class _FormModel {
  final String textField;
  final bool toggle;

  _FormModel({
    required this.textField,
    required this.toggle,
  });

  _FormModel copyWith({
    String? textField,
    bool? toggle,
  }) =>
      _FormModel(
        textField: textField ?? this.textField,
        toggle: toggle ?? this.toggle,
      );
}

class TextFieldPage extends StatelessWidget {
  const TextFieldPage({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final formKey = GlobalKey<FormState>();

    return BasicScaffold(
      title: "Text Field",
      body: _PageBody(formKey: formKey),
    );
  }
}

class _PageBody extends HookWidget {
  const _PageBody({
    Key? key,
    required this.formKey,
  }) : super(key: key);

  final GlobalKey<FormState> formKey;

  @override
  Widget build(BuildContext context) {
    final formModelConsumer = useProvider(_formModelProvider);

    return Padding(
      padding: const EdgeInsets.all(16.0),
      child: SingleChildScrollView(
        child: Form(
          key: formKey,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              BasicTextField(
                label: "Text Field",
                defaultValue: formModelConsumer.state.textField,
                borderWidth: 0,
                fillColor: Colors.grey[200],
                borderRadius: 10,
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'Please enter some text';
                  }
                  return null;
                },
                onChanged: (value) {
                  formModelConsumer.state =
                      formModelConsumer.state.copyWith(textField: value);
                },
              ),
              const SizedBox(height: 16),
              BasicToggle(
                label: "Toggle",
                value: formModelConsumer.state.toggle,
                onChanged: (value) {
                  formModelConsumer.state =
                      formModelConsumer.state.copyWith(toggle: value);
                },
              ),
              const SizedBox(height: 16),
              BasicText(
                "TextField value: ${formModelConsumer.state.textField}",
              ),
              BasicText(
                "Toggle value: ${formModelConsumer.state.toggle}",
              ),
              const SizedBox(height: 16),
              BasicButton("Validate", onPressed: () {
                formKey.currentState!.validate();
              })
            ],
          ),
        ),
      ),
    );
  }
}
