import 'package:basic_ui/src/providers/theme_provider.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';

import '../models/basic_drawer_menu.dart';
import 'basic_text.dart';

/// Creates a [BasicDrawer].
class BasicDrawer extends HookWidget {
  const BasicDrawer({
    Key? key,
    this.title,
    this.menus,
  }) : super(key: key);

  /// A text to display on the header of [BasicDrawer].
  final String? title;

  /// A list of drawer menu
  final List<List<BasicDrawerMenu>>? menus;

  @override
  Widget build(BuildContext context) {
    final theme = useProvider(themeProvider).theme;

    final List<Widget> drawerMenus = [];

    if (title != null) {
      drawerMenus.add(Padding(
        padding: const EdgeInsets.all(16.0),
        child: BasicText(title!),
      ));
    }

    for (final menu in menus!) {
      drawerMenus.add(Divider(color: theme.borderColor));
      for (final item in menu) {
        drawerMenus.add(ListTile(
          leading: item.icon != null
              ? Icon(item.icon, color: theme.fontColor)
              : null,
          title: BasicText(item.title, variant: BasicTextVariant.small),
          onTap: () {
            Navigator.pop(context);
            if (item.page != null) {
              Navigator.push(
                  context, MaterialPageRoute(builder: (context) => item.page!));
            }
            if (item.onClick != null) {
              item.onClick!();
            }
          },
          dense: true,
        ));
      }
    }

    return Theme(
      data: Theme.of(context).copyWith(canvasColor: theme.backgroundColor),
      child: Drawer(
        child: SafeArea(
          child: NotificationListener<OverscrollIndicatorNotification>(
            onNotification: (overscroll) {
              overscroll.disallowGlow();
              return true;
            },
            child: ListView(children: drawerMenus),
          ),
        ),
      ),
    );
  }
}
