import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';

/// This Widget is a wrapper for a [GestureDetector] with [AnimatedOpacity] Widget,
/// used to make non-tapable Widgets tappable
class BasicTap extends HookWidget {
  const BasicTap({
    Key? key,
    this.onTap,
    this.onLongPress,
    this.child,
  }) : super(key: key);

  /// The callback when [BasicTap] is tapped.
  final Function()? onTap;

  /// The callback when [BasicToggle] is long pressed.
  final Function()? onLongPress;

  /// The widget below this widget in the tree.
  final Widget? child;

  @override
  Widget build(BuildContext context) {
    final showTapEffect = useState(false);

    return GestureDetector(
      onTap: onTap,
      onLongPress: onLongPress,
      onTapDown: (detail) {
        if (onLongPress != null || onTap != null) {
          showTapEffect.value = true;
        }
      },
      onTapUp: (detail) {
        if (onLongPress != null || onTap != null) {
          showTapEffect.value = false;
        }
      },
      onTapCancel: () {
        if (onLongPress != null || onTap != null) {
          showTapEffect.value = false;
        }
      },
      child: AnimatedOpacity(
        opacity: showTapEffect.value ? .50 : 1,
        duration: const Duration(milliseconds: 50),
        child: Container(
          decoration: const BoxDecoration(),
          child: child,
        ),
      ),
    );
  }
}
