import 'package:flutter/material.dart';

import 'basic_text.dart';

/// A toggle represents a physical switch that allows someone to choose
/// between two mutually exclusive options. For example, “On/Off”, “Show/Hide”.
/// Choosing an option should produce an immediate result.
class BasicToggle extends StatelessWidget {
  const BasicToggle({
    Key? key,
    required this.label,
    this.labelVariant = BasicTextVariant.label,
    this.labelColor,
    this.fontWeight,
    required this.value,
    this.inline = true,
    required this.onChanged,
  }) : super(key: key);

  /// Text to display as [BasicToggle] label.
  final String label;

  /// label variant [BasicTextVariant].
  final BasicTextVariant labelVariant;

  /// label color.
  final Color? labelColor;

  /// label font weight.
  final FontWeight? fontWeight;

  /// Current value of [BasicToggle].
  final bool value;

  /// Set this to true to make toggle and label in same line.
  final bool inline;

  /// The callback when [BasicToggle] value is changed.
  final Function(bool)? onChanged;

  @override
  Widget build(BuildContext context) {
    if (inline) {
      return Row(
        children: [
          BasicText(
            label,
            variant: labelVariant,
            color: labelColor,
            fontWeight: fontWeight,
          ),
          const Spacer(),
          Switch(value: value, onChanged: onChanged)
        ],
      );
    }

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        BasicText(
          label,
          variant: labelVariant,
          color: labelColor,
          fontWeight: fontWeight,
        ),
        const SizedBox(height: 4),
        Switch(value: value, onChanged: onChanged)
      ],
    );
  }
}
